@@ -29,8 +29,12 @@ test_that("category_types returns as expected", {
 
 context("nearest_neighbours works correctly")
 test_that("nearest_neighbours returns as expected", {
-        expect_is(nearest_neighbours(AreaCode = "E10000007", AreaTypeID = 102), "character")
+        expect_is(nearest_neighbours(AreaCode = "E06000007", AreaTypeID = 101), "character")
+        expect_is(nearest_neighbours(AreaCode = "E10000007", AreaTypeID = 102, measure = "CIPFA"), "character")
+        expect_is(nearest_neighbours(AreaCode = "E10000007", AreaTypeID = 102, measure = "CSSN"), "character")
         expect_is(nearest_neighbours(AreaCode = "E38000022", AreaTypeID = 153), "character")
         expect_error(nearest_neighbours(AreaCode = "E12000001", AreaTypeID = 6), "AreaTypeID must be one of 101, 102, 152 or 153")
         expect_error(nearest_neighbours(AreaCode = "E07000033", AreaTypeID = 152), "E07000033 not in AreaTypeID = 152")
+        expect_error(nearest_neighbours(AreaCode = "E10000007", AreaTypeID = 102), "If using AreaTypeID = 102, you must specify measure \\(CIPFA or CSSN\\)")
+        expect_error(nearest_neighbours(AreaCode = "E10000007", AreaTypeID = 102, measure = "CIPPA"), "Measure must be either CIPFA or CSSN")
 })
